/**
 * Represents a integer-valued filter parameter.
 */
public class IntFilterParam extends FilterParam {
	private final String name;
	private final int min;
	private final int max;
	private int value;
	
	// ### INIT ###
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Integer.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Integer.MAX_VALUE</tt> to indicate an unbounded maximum
	 */
	public IntFilterParam(String name, int min, int max) {
		this(name, min, max, min);
	}
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Integer.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Integer.MAX_VALUE</tt> to indicate an unbounded maximum
	 * @param value	the initial value of this parameter
	 */
	public IntFilterParam(String name, int min, int max, int value) {
		this.name = name;
		this.min = min;
		this.max = max;
		this.setValue(value);
	}
	
	// ### ACCESSORS ###
	
	public String getName() {
		return this.name;
	}
	
	public int getMin() {
		return this.min;
	}
	
	public int getMax() {
		return this.max;
	}
	
	public int getValue() {
		return this.value;
	}
	
	public void setValue(int value) {
		if (value < this.min)
			throw new IllegalArgumentException(
				"value out of range (value < min): "+value+" < "+min);
		if (value > this.max)
			throw new IllegalArgumentException(
				"value out of range (value > max): "+value+" > "+max);
		this.value = value;
	}
}